@@ -22,10 +22,14 @@ BOOL rdp_connect(char *server, int32_t port, char *domain, char *login, char *pa
   instance->settings->Username = login;
   instance->settings->Password = password;
   instance->settings->IgnoreCertificate = TRUE;
-  instance->settings->AuthenticationOnly = TRUE;
+  if (password[0] == 0)
+    instance->settings->AuthenticationOnly = FALSE;
+  else
+    instance->settings->AuthenticationOnly = TRUE;
   instance->settings->ServerHostname = server;
   instance->settings->ServerPort = port;
   instance->settings->Domain = domain;
+  instance->settings->MaxTimeInCheckLoop = 100;
   freerdp_connect(instance);
   err = freerdp_get_last_error(instance->context);
   return err;
@@ -54,6 +58,7 @@ int32_t start_rdp(char *ip, int32_t port, unsigned char options, char *miscptr,
   }
 
   login_result = rdp_connect(server, port, domain, login, pass);
+  if (debug) hydra_report(stderr, "[DEBUG] rdp reported %08x\n", login_result);
   switch (login_result) {
   case 0:
     // login success
